Name:           radare2
Summary:        The reverse engineering framework
Version:        5.9.8
URL:            https://radare.org/
%global         vcsurl          https://github.com/radareorg/radare2
VCS:            https://github.com/radareorg/radare2/releases


%global         gituser         radareorg
%global         gitname         radare2
%global         gitdate         20241119
%global         commit          4eb49d5ad8c99eaecc8850a2f10bad407067c898
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

%global         autorelease    1%{?dist}


Release:        1%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

Patch1:         radare2-5.6.6-use_openssl.patch
Patch3:         radare2-5.9.0-use_magic.patch

Patch7:         radare2-5.9.8-dec99.patch

License:        LGPL-3.0-or-later AND GPL-2.0-or-later AND BSD-2-Clause AND BSD-3-Clause AND MIT AND Apache-2.0 AND MPL-2.0 AND Zlib

BuildRequires:  sed
BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  ninja-build
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxxhash)

BuildRequires:  pkgconfig(libzip)

BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(capstone) >= 3.0.4
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(openssl)

BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(bzip2)

Requires:       %{name}-common = %{version}-%{release}

Provides:       bundled(spp) = 1.2.0
Provides:       bundled(sdb) = 1.8.6
Provides:       bundled(js0n) = 2018
Provides:       bundled(openbsdregex) = 1.11
Provides:       bundled(tcc) = 0.9.26
Provides:       bundled(binutils) = 2.13
Provides:       bundled(vavrdisasm) = 1.6
Provides:       bundled(grub2) = 1.99~beta0
Provides:       bundled(ptrace-wrap) = 20181018
Provides:       bundled(tree-sitter) = 0.17.2
Provides:       bundled(mpc) = 0.8.7
Provides:       bundled(yxml) = 20201108
Provides:       bundled(quickjs-ng) = 0.7.0


%description
The radare2 is a reverse-engineering framework that is multi-architecture,
multi-platform, and highly scriptable.  Radare2 provides a hexadecimal
editor, wrapped I/O, file system support, debugger support, diffing
between two functions or binaries, and code analysis at opcode,
basic block, and function levels.


%package devel
Summary:        Development files for the radare2 package
Requires:       %{name} = %{version}-%{release}
Requires:       file-devel
Requires:       openssl-devel

%description devel
Development files for the radare2 package. See radare2 package for more
information.


%package common
Summary:        Arch-independent SDB files for the radare2 package
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description common
Arch-independent SDB files used by radare2 package. See radare2 package for more
information


%prep
%autosetup -p 1 -n %{gitname}-%{version}
rm -rf shlr/zip/{zip,zlib,include}

rm -rf shlr/lz4/{deps.mk,LICENSE,lz4.*,Makefile,README.md}
rm -f libr/hash/xxhash.c libr/hash/xxhash.h
awk 'BEGIN {p=1} /#if USE_LIB_MAGIC/ {p=2; next} p==2 && /#else/ {p=0} p>0 {print}' libr/magic/magic.c > libr/magic/magic.c.stripped
awk 'BEGIN {p=1} /#if !USE_LIB_MAGIC/ {p=0; next} p==2 && /#else/ {p=0} p>0 {print}' libr/magic/ascmagic.c > libr/magic/ascmagic.c.stripped
rm -rf libr/magic/*.c
mv libr/magic/magic.c.stripped libr/magic/magic-libmagic.c
mv libr/magic/ascmagic.c.stripped libr/magic/ascmagic-libmagic.c

rm -rf ./shlr/www/*
echo "The radare2 source usually comes with a pre-built version of the web-interface, but without the source code." > ./shlr/www/README
echo "This has been removed in the OpenCloudOS package to follow the OpenCloudOS Packaging Guidelines." >> ./shlr/www/README
echo "Available under https://github.com/radare/radare2-webui" >> ./shlr/www/README


sed -i -e "s|/usr/bin/env -S r2|/usr/bin/r2|" ./scripts/licenses.r2.js

%build

%meson \
    -Duse_sys_magic=true \
    -Duse_sys_zip=true \
    -Duse_sys_zlib=true \
    -Duse_sys_lz4=true \
    -Duse_sys_xxhash=true \
    -Duse_ssl=true \
    -Duse_libuv=true \
    -Duse_sys_capstone=true \
    -Denable_tests=false \
    -Denable_r2r=false \
    -Dwant_threads=false     # multithreading doesn't work well with Iaito package
%meson_build


%install
%meson_install
mkdir -p %{buildroot}/%{_datadir}/%{name}/%{version}/www
cp ./shlr/www/README %{buildroot}/%{_datadir}/%{name}/%{version}/www/README
rm %{buildroot}/%{_datadir}/doc/%{name}/fortunes.fun

mkdir -p %{buildroot}%{_libdir}/%{name}/%{version}


%check


%files
%license COPYING COPYING.LESSER
%doc CONTRIBUTING.md DEVELOPERS.md README.md
%doc doc/3D/ doc/pdb/ doc/sandbox/
%doc doc/avr.md doc/brainfuck.md doc/calling-conventions.md doc/debug.md
%doc doc/esil.md doc/gdb.md doc/gprobe.md doc/intro.md doc/io.md doc/rap.md
%doc doc/siol.md doc/strings.md doc/windbg.md doc/yara.md
%doc %{_datadir}/doc/%{name}/fortunes.tips
%dir %{_datadir}/%{name}/%{version}/www
%doc %{_datadir}/%{name}/%{version}/www/README
%{_bindir}/r*
%{_libdir}/libr_*.so.%{version}*
%{_libdir}/%{name}
%{_mandir}/man1/r*.1.*
%{_mandir}/man7/esil.7.*
%{_datadir}/zsh/site-functions/_r*


%files devel
%{_includedir}/libr
%{_libdir}/libr*.so
%{_libdir}/pkgconfig/*.pc


%files common
%{_datadir}/%{name}/%{version}/cons
%{_datadir}/%{name}/%{version}/fcnsign
%{_datadir}/%{name}/%{version}/flag
%{_datadir}/%{name}/%{version}/format
%{_datadir}/%{name}/%{version}/hud
%{_datadir}/%{name}/%{version}/magic
%{_datadir}/%{name}/%{version}/opcodes
%{_datadir}/%{name}/%{version}/syscall
%{_datadir}/%{name}/%{version}/charsets
%{_datadir}/%{name}/%{version}/platform
%{_datadir}/%{name}/%{version}/scripts

%dir %{_datadir}/%{name}
%dir %{_datadir}/doc/%{name}
%dir %{_datadir}/%{name}/%{version}


%changelog
* Tue Dec 03 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.9.8-1
- [Type] security
- [DESC] Fix CVE-2024-48241

* Fri Nov 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.9.4-1
- fix CVE-2023-46569 CVE-2023-46570

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.8-1
- initial build

